@@ -1,26 +1,13 @@
 /*
-   Copyright (C) 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "evolutionsettings.h"
 #include "evolutionutil.h"
 #include <MailCommon/MailUtil>
-#include <ImportWizard/ImportWizardUtil>
+#include "importwizardutil.h"
 
 #include <KIdentityManagement/kidentitymanagement/identity.h>
 
@@ -62,8 +49,8 @@ void EvolutionSettings::loadAccount(const QString &filename)
     for (QDomElement e = config.firstChildElement(); !e.isNull(); e = e.nextSiblingElement()) {
         const QString tag = e.tagName();
         if (tag == QLatin1String("entry")) {
-            if (e.hasAttribute("name")) {
-                const QString attr = e.attribute("name");
+            if (e.hasAttribute(QLatin1String("name"))) {
+                const QString attr = e.attribute(QLatin1String("name"));
                 if (attr == QLatin1String("accounts")) {
                     readAccount(e);
                 } else if (attr == QLatin1String("signatures")) {
@@ -286,7 +273,7 @@ void EvolutionSettings::extractAccountInfo(const QString &info)
                 } else if (identityTag == QLatin1String("organization")) {
                     newIdentity->setOrganization(identity.text());
                 } else if (identityTag == QLatin1String("signature")) {
-                    if (identity.hasAttribute("uid")) {
+                    if (identity.hasAttribute(QStringLiteral("uid"))) {
                         newIdentity->setSignature(mMapSignature.value(identity.attribute(QStringLiteral("uid"))));
                     }
                 } else if (identityTag == QLatin1String("reply-to")) {
